@@ -28,18 +28,19 @@
 #include <vector>
 #include <array>
 
-#include <osmscout/CoreImportExport.h>
+#include <osmscout/lib/CoreImportExport.h>
 
 #include <osmscout/ObjectRef.h>
 #include <osmscout/OSMScoutTypes.h>
 #include <osmscout/Tag.h>
 #include <osmscout/TypeFeature.h>
 
-#include <osmscout/util/FileScanner.h>
-#include <osmscout/util/FileWriter.h>
 #include <osmscout/util/TagErrorReporter.h>
 #include <osmscout/util/Number.h>
 
+#include <osmscout/io/FileScanner.h>
+#include <osmscout/io/FileWriter.h>
+
 #include <osmscout/system/Assert.h>
 
 #include <osmscout/system/Compiler.h>
@@ -1040,13 +1041,13 @@ namespace osmscout {
   // Forward declaration
   class TypeConfig;
 
-  static const uint32_t FILE_FORMAT_VERSION=24;
+  static const uint32_t FILE_FORMAT_VERSION=25;
 
   /**
    * \ingroup type
    *
    * The TypeConfig class holds information about object types
-   * defined by a database instance.
+   * defined by a db instance.
    */
   class OSMSCOUT_API TypeConfig CLASS_FINAL
   {
@@ -1100,6 +1101,7 @@ namespace osmscout {
     FeatureRef                                  featureEmbankment;
     FeatureRef                                  featureRoundabout;
     FeatureRef                                  featureLanes;
+    FeatureRef                                  featureOpeningHours;
 
   public:
     // Internal use (only available during preprocessing)
